Change log
==========

This document records all notable changes to `PyRish <https://pypi.python.org/pypi/pyrish>`_.

`0.3.0`_ (2018-30-01)
---------------------

# Added
    - added ``shell`` module

# Changed
    - moved ``run_shell`` from ``utils`` module to ``shell`` module
    - ``itertools.last`` raises ``EmptyIterableError`` exception instead of ``StopIteration``
    - ``itertools.first`` raises ``EmptyIterableError`` exception instead of ``StopIteration``

`0.2.0`_ (2018-29-01)
---------------------

# Added
    - added ``itertools`` module
    - added ``types`` module

`0.1.0`_ (2018-24-01)
---------------------

# First release on PyPI.

.. _0.3.0: https://pypi.python.org/packages/8d/51/6875d0392e9e6972b753319d9f2d6e662e2aa490663ec170f06f4b103b59/pyrish-0.3.0.tar.gz
.. _0.2.0: https://pypi.python.org/packages/06/c7/1b8d53e417d543dc55419d273ea019c1ac343c92dd5a183e3b1f9fe9e700/pyrish-0.2.0.tar.gz
.. _0.1.0: https://pypi.python.org/packages/2a/e0/7d4cf0cb38921582be305b7435ec19ab07c1e56bcb210bdefd16e25da3bb/pyrish-0.1.0.tar.gz
